@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.110';
+$System::Command::VERSION = '1.111';
 use warnings;
 use strict;
 use 5.006;
@@ -222,6 +222,8 @@ sub new {
 
     # update the environment
     if ( exists $o->{env} ) {
+        croak "ENV variables cannot be empty strings on Win32"
+            if MSWin32 and grep { defined and !length } values %{ $o->{env} };
         @ENV{ keys %{ $o->{env} } } = values %{ $o->{env} };
         delete $ENV{$_}
             for grep { !defined $o->{env}{$_} } keys %{ $o->{env} };
@@ -292,7 +294,7 @@ System::Command - Object for running system commands
 
 =head1 VERSION
 
-version 1.110
+version 1.111
 
 =head1 SYNOPSIS
 
@@ -420,7 +422,7 @@ At trace level 2, the options values are shown:
     System::Command opt[12834]: fatal => {128 => 1,129 => 1}
     System::Command opt[12834]: git => "/usr/bin/git"
 
-Note: The C<fatal> and C<git> options in the example above is actually
+Note: The C<fatal> and C<git> options in the example above are actually
 used by L<Git::Repository> to determine the command to be run, and
 ignored by System::Command. References are dumped using L<Data::Dumper>.
 
@@ -432,7 +434,7 @@ At trace level 3, the content of the C<env> option is also listed:
 If the command cannot be spawned, the trace will show C<!> instead of
 the pid:
 
-    System::Command: ! - does-not-exist
+    System::Command cmd[!]: does-not-exist
 
 =back
 
